@@ -20,12 +20,12 @@
 
 #include "editactiondialog.h"
 
+#include <QIcon>
 #include <QItemDelegate>
 #include <QComboBox>
 #include "klipper_debug.h"
 #include <QDialogButtonBox>
 
-#include <KIconLoader>
 #include <kwindowconfig.h>
 #include <KWindowConfig>
 
@@ -101,7 +101,7 @@ class ActionDetailModel : public QAbstractTableModel {
             DESCRIPTION_COL = 2
         };
         QList<ClipCommand> m_commands;
-        QVariant displayData(ClipCommand* command, column_t colunm) const;
+        QVariant displayData(ClipCommand* command, column_t column) const;
         QVariant editData(ClipCommand* command, column_t column) const;
         QVariant decorationData(ClipCommand* command, column_t column) const;
         void setIconForCommand(ClipCommand& cmd);
@@ -129,12 +129,7 @@ void ActionDetailModel::setIconForCommand(ClipCommand& cmd)
         command = command.section( QLatin1Char(' '), 0, 0 );
     }
 
-    QPixmap iconPix = KIconLoader::global()->loadIcon(
-                                        command, KIconLoader::Small, 0,
-                                        KIconLoader::DefaultState,
-                                        QStringList(), nullptr, true /* canReturnNull */ );
-
-    if ( !iconPix.isNull() ) {
+    if (QIcon::hasThemeIcon(command)) {
         cmd.icon = command;
     } else {
         cmd.icon.clear();
